@@ -1,38 +1,15 @@
 
 /*
-   Copyright (c) 2003-2007 Clarence Dang <dang@kde.org>
-   All rights reserved.
+   SPDX-FileCopyrightText: 2003-2007 Clarence Dang <dang@kde.org>
 
-   Redistribution and use in source and binary forms, with or without
-   modification, are permitted provided that the following conditions
-   are met:
-
-   1. Redistributions of source code must retain the above copyright
-      notice, this list of conditions and the following disclaimer.
-   2. Redistributions in binary form must reproduce the above copyright
-      notice, this list of conditions and the following disclaimer in the
-      documentation and/or other materials provided with the distribution.
-
-   THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
-   IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
-   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
-   IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
-   INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
-   NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
-   DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
-   THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
-   (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
-   THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+   SPDX-License-Identifier: BSD-2-Clause
 */
 
-
 #ifndef kpToolEnvironment_H
 #define kpToolEnvironment_H
 
-
 #include "environments/kpEnvironmentBase.h"
 
-
 class QActionGroup;
 class QPoint;
 class QRect;
@@ -44,40 +21,38 @@ class kpColor;
 class kpCommandHistory;
 class kpToolToolBar;
 
-
 // Facade for kpTool clients.
 class kpToolEnvironment : public kpEnvironmentBase
 {
-Q_OBJECT
+    Q_OBJECT
 
 public:
     // Note: Our interface must never publicly leak <mainWindow> or any other
     //       classes we are trying to hide as that would defeat the point of
     //       the facade.
-    explicit kpToolEnvironment (kpMainWindow *mainWindow);
-    ~kpToolEnvironment () override;
+    explicit kpToolEnvironment(kpMainWindow *mainWindow);
+    ~kpToolEnvironment() override;
 
+    KActionCollection *actionCollection() const;
 
-    KActionCollection *actionCollection () const;
+    kpCommandHistory *commandHistory() const;
 
-    kpCommandHistory *commandHistory () const;
+    QActionGroup *toolsActionGroup() const;
+    kpToolToolBar *toolToolBar() const;
+    void hideAllToolWidgets() const;
+    bool selectPreviousTool() const;
 
-    QActionGroup *toolsActionGroup () const;
-    kpToolToolBar *toolToolBar () const;
-    void hideAllToolWidgets () const;
-    bool selectPreviousTool () const;
-
-    kpColor color (int which) const;
-    double colorSimilarity () const;
-    int processedColorSimilarity () const;
+    kpColor color(int which) const;
+    double colorSimilarity() const;
+    int processedColorSimilarity() const;
 
     // (only valid in kpTool::slotForegroundColorChanged())
-    kpColor oldForegroundColor () const;
+    kpColor oldForegroundColor() const;
     // (only valid in kpTool::slotBackgroundColorChanged())
-    kpColor oldBackgroundColor () const;
+    kpColor oldBackgroundColor() const;
 
     // (only valid in kpTool::slotColorSimilarityChanged())
-    double oldColorSimilarity () const;
+    double oldColorSimilarity() const;
 
     // Flashes the Color Similarity Tool Bar Item to highlight to the user,
     // the existence of the Color Similarity feature.
@@ -129,35 +104,31 @@ public:
     //
     // We flash in tools but not commands as else it would be very distracting
     // Undo/Redo - this flashing in the tools is distracting enough already :)
-    void flashColorSimilarityToolBarItem () const;
+    void flashColorSimilarityToolBarItem() const;
 
-    void setColor (int which, const kpColor &color) const;
+    void setColor(int which, const kpColor &color) const;
 
-    void deleteSelection () const;
-    void pasteTextAt (const QString &text, const QPoint &point,
-                      // Allow tiny adjustment of <point> so that mouse
-                      // pointer is not exactly on top of the topLeft of
-                      // any new text selection (so that it doesn't look
-                      // weird by being on top of a resize handle just after
-                      // a paste).
-                      bool allowNewTextSelectionPointShift = false) const;
+    void deleteSelection() const;
+    void pasteTextAt(const QString &text,
+                     const QPoint &point,
+                     // Allow tiny adjustment of <point> so that mouse
+                     // pointer is not exactly on top of the topLeft of
+                     // any new text selection (so that it doesn't look
+                     // weird by being on top of a resize handle just after
+                     // a paste).
+                     bool allowNewTextSelectionPointShift = false) const;
 
-    void zoomIn (bool centerUnderCursor = false) const;
-    void zoomOut (bool centerUnderCursor = false) const;
+    void zoomIn(bool centerUnderCursor = false) const;
+    void zoomOut(bool centerUnderCursor = false) const;
 
-    void zoomToRect (const QRect &normalizedDocRect,
-        bool accountForGrips,
-        bool careAboutWidth, bool careAboutHeight) const;
+    void zoomToRect(const QRect &normalizedDocRect, bool accountForGrips, bool careAboutWidth, bool careAboutHeight) const;
 
-    void fitToPage () const;
+    void fitToPage() const;
 
     static bool drawAntiAliased;
 
-
 private:
-    struct kpToolEnvironmentPrivate * const d;
+    struct kpToolEnvironmentPrivate *const d;
 };
 
-
-#endif  // kpToolEnvironment_H
-
+#endif // kpToolEnvironment_H
